@@ -15,14 +15,14 @@ cat("dse1 test 7a...\n")
   A[1,,] <- diag(1,length(true.roots))
   A[2,,] <- diag(-true.roots, length(true.roots))
   # the following relies on roots using by.poly=FALSE
-  if(is.Splus()) options(expressions=1024)
+  if(!is.R()) options(expressions=1024)# really if(is.Splus())
    tst <-  sort(roots( ARMA(A=A, B=diag(1,length(true.roots)) ),by.poly=FALSE))
    good <- sort(true.roots)
    error <- max(Mod(good - tst))
    cat("max. error ", max(error))
 
    if (any(is.na(error)) || any(is.nan(error)) || fuzz.small < error ) 
-     {print.test.value(c(tst), digits=18)
+     {printTestValue(c(tst), digits=18)
       all.ok <- FALSE  
      }
 
@@ -48,8 +48,8 @@ cat("dse1 test 7b...\n")
    cat("max. error ", max(error))
 
    if (any(is.na(error)) || any(is.nan(error)) || fuzz.small < error ) 
-     {print.test.value(c(z), digits=18)
-      print.test.value(c(zz), digits=18)
+     {printTestValue(c(z), digits=18)
+      printTestValue(c(zz), digits=18)
       all.ok <- FALSE  
      }
 
@@ -61,8 +61,8 @@ cat("dse1 test 7c...\n")
    cat("max. error ", max(error))
 
    if (any(is.na(error)) || any(is.nan(error)) || fuzz.small < error ) 
-     {print.test.value(c(z), digits=18)
-      print.test.value(c(zz), digits=18)
+     {printTestValue(c(z), digits=18)
+      printTestValue(c(zz), digits=18)
       all.ok <- FALSE  
      }
 
